﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using HeuristicLab.Core;

namespace HeuristicLab.Encodings.ParameterConfigurationEncoding {
  public interface IOptimizable : IItem {
    bool IsOptimizable { get; }
    bool Optimize { get; set; }
    ConstrainedValue ActualValue { get; set; }

    void Randomize(IRandom random);
    string ParameterInfoString { get; }
    void CollectOptimizedParameterNames(List<string> parameterNames, string prefix);
    double CalculateSimilarity(IOptimizable optimizable);

    /// <summary>
    /// Recursively gets all optimizables which have Optimize=true
    /// </summary>
    List<IOptimizable> GetAllOptimizables();

    event EventHandler IsOptimizableChanged;
    event EventHandler OptimizeChanged;
    event EventHandler CombinationsCountChanged;

    /// <summary>
    /// indicates if the actualvalues are modifiable
    /// </summary>
    bool ValuesReadOnly { get; set; }
  }
}
